const products = [
    { id: 1, name: 'Sangre y Cenizas', price: 100.00, img: "img/1.jpg" },
    { id: 2, name: 'El caballero astado', price: 200.00, img: "img/2.jpg" },
    { id: 3, name: 'Corazón de tinta', price: 400.00, img: "img/3.jpg" },
    { id: 4, name: 'Seis de cuervos', price: 700.00, img: "img/4.jpg" },
    { id: 5, name: 'El ocaso de hielo', price: 800.00, img: "img/5.jpg" },
    { id: 6, name: 'Señor de los anillos: comunidad del anillo', price: 300.00, img: "img/6.jpg" },
    { id: 7, name: 'El Hobbit', price: 200.00, img: "img/7.jpg" },
    { id: 8, name: 'Harry Potter y la camara secreta ', price: 50.00, img: "img/8.jpg" },
];

let cart = [];

function showProducts() {
    const $productList = $('#product-list');
    
    products.forEach(product => {
        const productCard = `
            <div class="col mb-5">
                        <div class="card h-100">
                            <img class="card-img-top" src="${product.img}" alt="..." />
                            <div class="card-body p-4">
                                <div class="text-center">
                                    <h5 class="fw-bolder">${product.name}</h5>
                                    ₡${product.price.toFixed(2)}
                                </div>
                            </div>
                            <div class="card-footer p-4 pt-0 border-top-0 bg-transparent">
                                <div class="text-center"><button class="btn btn-outline-dark add-to-cart" data-id="${product.id}">Añadir al carrito</button></div>
                            </div>
                        </div>
                    </div>
                    `;
        
        $productList.append(productCard);
    });
}

function addToCart(id) {
    const product = products.find(p => p.id === id);
    cart.push(product);
    updateCartCount();

    toastr.success(`${product.name} ha sido agregado al carrito!`, "Producto Agregado", {
        closeButton: true,
        progressBar: true,
        timeOut: "2000"
    });
}

function updateCartCount() {
    $('#cart-count').text(cart.length);
    boton_carrito();
}

function showCart() {
    const $cartItems = $('#cart-items');
    $cartItems.empty();

    if (cart.length === 0) {
        $cartItems.append('<li class="list-group-item">Tu carrito está vacío.</li>');
        $('#cartModal').modal('hide');
    } else {
        cart.forEach(product => {
            const item = `
                <li class="list-group-item d-flex justify-content-between align-items-center">
                    <div>
                        <img src="${product.img}" alt="${product.name}" class="img-thumbnail" style="width: 50px; height: auto; margin-right: 10px;">
                        ${product.name}
                    </div>
                    <span>₡${product.price.toFixed(2)}</span>
                    <button class="btn btn-danger btn-sm remove-from-cart" data-index="${product.id}">Eliminar</button>
                </li>`;
            $cartItems.append(item);
        });
    }

    $('#total-price').text(`₡${getTotalPrice()}`);
    $('#cartModal').modal('show');
}


function getTotalPrice() {
    return cart.reduce((total, product) => total + product.price, 0).toFixed(2);
}

function boton_carrito() {
    const $btn_carrito = $('#cart-btn');

   
    if (cart.length > 0) {
        $btn_carrito.prop('disabled', false); 
    } else {
        $btn_carrito.prop('disabled', true); 
    }
}

function removeFromCart(index) {

    cart = cart.filter(product => product.id !== index);
    console.log(cart);
     
    updateCartCount(); 
    showCart(); 
}

$(document).ready(() => {
    showProducts();

    $('#product-list').on('click', '.add-to-cart', function () {
        const id = $(this).data('id');
        addToCart(id);
    });

    $('#cart-btn').on('click', showCart);
    
    // Manejador de eventos para el botón de eliminar
    $(document).on('click', '.remove-from-cart', function () {
        const index = $(this).data('index');
        removeFromCart(index);
        
    });

});
